==> haskell-hls-class-plugin-2.0.0.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-class-plugin-2.0.0.0-1LotifFh09RAN54NhtYt4T
key:                  hls-class-plugin-2.0.0.0-1LotifFh09RAN54NhtYt4T
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  6f67772dcfd59434db18e5a470f0ebd1
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.0.0.0-1LotifFh09RAN54NhtYt4T
depends:
    aeson-2.1.2.1-BogEXKsQPCa9ALgQQ034ff base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-EuapY98rdrN25pzQYLq3T2 ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-Hhg3PMpjpEKL9mhLS9uk3b
    ghcide-2.0.0.0-239vuqwqb9AHEMUTpbpyg
    hls-graph-2.0.0.0-HgPfBJlhdFI6RSqKDfLWYh
    hls-plugin-api-2.0.0.0-C4KP5NWWuu59l1jOYt9ljX
    lens-5.2.3-CUB7er19pGW1jvefO3TVCG
    lsp-1.6.0.0-2KeiYBxXLvVGpdNjURDfN5 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-class-plugin-2.0.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-class-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-class-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-class-plugin-2.0.0.0-AyHLqvWHZ9LF6eqdCcQnW0
key:                  hls-class-plugin-2.0.0.0-AyHLqvWHZ9LF6eqdCcQnW0
license:              Apache-2.0
maintainer:           jjc9310@gmail.com
author:               Junyoung Clare Jang
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:
    Class/instance management plugin for Haskell Language Server

description:
    Class/instance management plugin for Haskell Language Server.
    For usage, please see README of HLS on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  be0290e160dadf6dc1f56f3fcadd5d58
exposed:              True
exposed-modules:      Ide.Plugin.Class
hidden-modules:
    Ide.Plugin.Class.CodeAction Ide.Plugin.Class.CodeLens
    Ide.Plugin.Class.ExactPrint Ide.Plugin.Class.Types
    Ide.Plugin.Class.Utils

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-class-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-class-plugin
hs-libraries:         HShls-class-plugin-2.0.0.0-AyHLqvWHZ9LF6eqdCcQnW0
depends:
    aeson-2.1.2.1-5ZyQo9G6Ms46oZtaJgJtcb base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 extra-1.7.16-3SBUeFH5sHLJDtonZSgAoM ghc-9.4.8
    ghc-boot-th-9.4.8 ghc-exactprint-1.6.1-JsvwkDVofg3BxdLE532wCX
    ghcide-2.0.0.0-3b9jhFA8f52IfzEBIRB0hj
    hls-graph-2.0.0.0-H6p9ajdQ0T36RwH1EZAbwJ
    hls-plugin-api-2.0.0.0-C6wcsLywVi7Dk1nbG5XhP7
    lens-5.2.3-9GV2xnL92otDGMRfTuRDyv
    lsp-1.6.0.0-FwDzb2GQtLRAHogbqVnKTH text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-class-plugin/html/hls-class-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-class-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
